@@ -560,7 +560,7 @@ fn test_escape_without_source() {
     es2020("abcde", "abcde");
     es2020(
         "\x00\r\n\u{85}\u{2028}\u{2029};",
-        "\\x00\\r\\n\\x85\u{2028}\u{2029};",
+        "\\x00\\r\\n\\x85\\u2028\\u2029;",
     );
 
     es2020("\n", "\\n");
